@@ -12,7 +12,9 @@ from typing import Any, Dict, Union
 import ignite
 import torch
 from ignite.contrib.handlers import TensorboardLogger
-from ignite.contrib.handlers.stores import EpochOutputStore
+from ignite.handlers.stores import EpochOutputStore
+
+# from ignite.contrib.handlers.stores import EpochOutputStore
 from ignite.handlers import EarlyStopping
 from ignite.contrib.handlers.tensorboard_logger import (
     global_step_from_engine,
